@@ -1,12 +1,15 @@
-#line 1 "inc/Module/Install/Include.pm - /usr/local/lib/perl5/site_perl/5.8.5/Module/Install/Include.pm"
+#line 1
 package Module::Install::Include;
 
-use Module::Install::Base;
-@ISA = qw(Module::Install::Base);
-
-$VERSION = '0.57';
-
 use strict;
+use Module::Install::Base ();
+
+use vars qw{$VERSION @ISA $ISCORE};
+BEGIN {
+	$VERSION = '0.94';
+	@ISA     = 'Module::Install::Base';
+	$ISCORE  = 1;
+}
 
 sub include {
 	shift()->admin->include(@_);
