@@ -1,7 +1,7 @@
 # BEGIN BPS TAGGED BLOCK {{{
 # COPYRIGHT:
 # 
-# This software is Copyright (c) 2003-2006 Best Practical Solutions, LLC
+# This software is Copyright (c) 2003-2008 Best Practical Solutions, LLC
 #                                          <clkao@bestpractical.com>
 # 
 # (Except where explicitly superseded by other copyright notices)
@@ -59,6 +59,7 @@ use SVK::Merge;
 use SVK::I18N;
 use YAML::Syck;
 use SVK::Logger;
+use SVK::Project;
 use autouse 'SVK::Util' => qw( reformat_svn_date );
 
 # XXX: provide -r which walks peg to the specified revision based on
@@ -94,9 +95,13 @@ sub _do_info {
 
     my ($m, $mpath) = $target->is_mirrored;
 
+    my ($proj) = SVK::Project->create_from_path(
+	         $target->depot, $target->path );
+
     $logger->info( loc("Checkout Path: %1\n",$target->copath))
 	if $target->isa('SVK::Path::Checkout');
     $logger->info( loc("Depot Path: %1\n", $target->depotpath));
+    $proj->info($target) if $proj;
     $logger->info( loc("Revision: %1\n", $target->revision));
     if (defined( my $lastchanged = $target->root->node_created_rev( $target->path ))) {
         $logger->info( loc( "Last Changed Rev.: %1\n", $lastchanged ));
@@ -150,7 +155,7 @@ For example, here's the way to display the info of a checkout path:
  Last Changed Rev.: 447
  Last Changed Date: 2006-11-28
  Copied From: /svk/trunk, Rev. 434
- Merge From: /svk/trunk, Rev. 445
+ Merged From: /svk/trunk, Rev. 445
 
 You can see the result has some basic information: the actual depot path,
 and current revision. Next are advanced information about copy and merge
@@ -160,7 +165,7 @@ The result of C<svk info //svk/local> is almost the same as above,
 except for the C<Checkout Path:> line is not there, because
 you are not referring to a checkout path.
 
-Note that the revision numbers on C<Copied From:> and C<Merge From:> lines
+Note that the revision numbers on C<Copied From:> and C<Merged From:> lines
 are for the source path (//svk/trunk), not the target path (//svk/local).
 The example above state that, I<//svk/local is copied from the revision 434
 of //svk/trunk>, and I<//svk/local was merged from the revision 445 of
